## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

%bcond_without  tests

# telemetry and testsdk don't follow azure-cli's versioning scheme.
# They have their own versions in the main repository.
%global         telemetry_version   1.0.6
%global         testsdk_version     0.3.0

%global         srcname     azure-cli
%global         forgeurl    https://github.com/Azure/azure-cli
Version:        2.33.1
%global         tag         %{srcname}-%{version}
%global         distprefix  %{nil}
%forgemeta

Name:           %{srcname}
Release:        %autorelease
Summary:        Microsoft Azure Command-Line Tools
License:        MIT
URL:            %forgeurl
Source0:        %forgesource
Patch0:         azure-cli-requirements-fix.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  pyproject-rpm-macros

%if %{with tests}
BuildRequires:  python3dist(azure-devtools)
BuildRequires:  python3dist(azure-mgmt-managedservices)
BuildRequires:  python3dist(pkginfo)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-xdist)
BuildRequires:  python3dist(vcrpy)
%endif

%description
Microsoft Azure Command-Line Tools

# python-azure-cli-core
%package -n python3-%{srcname}-core
Summary:        Microsoft Azure Command-Line Tools Core Module
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{srcname}-core
Microsoft Azure Command-Line Tools Core Module

# python-azure-cli-telemetry
%package -n python3-%{srcname}-telemetry
Summary:        Microsoft Azure CLI Telemetry Package
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{srcname}-telemetry
Microsoft Azure CLI Telemetry Package

# python-azure-cli-testsdk
%package -n python3-%{srcname}-testsdk
Summary:        Microsoft Azure CLI SDK testing tools
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{srcname}-testsdk
Microsoft Azure CLI SDK testing tools


%prep
%forgeautosetup -p1


%generate_buildrequires
%pyproject_buildrequires -N src/azure-cli/requirements.py3.Linux.txt


%build
PROJECTS=("azure-cli azure-cli-core azure-cli-telemetry azure-cli-testsdk")
for PROJECT in ${PROJECTS[@]}; do
    pushd src/${PROJECT}
        %pyproject_wheel
    popd
done


%install
%pyproject_install

# Batch scripts are only for Windows.
rm -f %{buildroot}%{_bindir}/az.bat

# Install the az bash completion script properly.
install -Dp %{buildroot}%{_bindir}/az.completion.sh %{buildroot}%{_datadir}/bash-completion/completions/%{name}
rm -f %{buildroot}%{_bindir}/az.completion.sh


%if %{with tests}
%check
# Test azure-cli-telemetry.
%pytest --boxed -n auto --disable-warnings src/azure-cli-telemetry

# Test azure-cli-core.
%pytest --boxed -n auto --disable-warnings src/azure-cli-core \
    -k "not test_get_mgmt_service_client \
        and not test_metadata_url_endpoints"

# Test azure-cli and command modules.
#
# NOTE(mhayden): 🤦🏻‍♂️ Skipping these as some depend on recordings of API calls,
# some depend on recordings that do not exist, and others must talk to various
# endpoints on the internet. Hopefully upstream can get these more
# self-contained soon.
%endif


%files
%doc README.md
%license LICENSE
# Executable-related files/directories.
%{_bindir}/az
# Bash completions.
%{_datadir}/bash-completion/completions/%{name}
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
# Python sitelib files and directories.
%dir %{python3_sitelib}/azure
%{python3_sitelib}/azure/cli
%{python3_sitelib}/azure_cli-%{version}.dist-info/
# Prevent azure-cli from grabbing all of the files underneath azure/cli.
%exclude %{python3_sitelib}/azure/cli/core
%exclude %{python3_sitelib}/azure/cli/telemetry
%exclude %{python3_sitelib}/azure/cli/testsdk


%files -n python3-%{srcname}-core
%doc README.md
%{python3_sitelib}/azure/cli/core
%{python3_sitelib}/azure_cli_core-%{version}.dist-info/


%files -n python3-%{srcname}-telemetry
%doc README.md
%{python3_sitelib}/azure/cli/telemetry
%{python3_sitelib}/azure_cli_telemetry-%{telemetry_version}.dist-info/


%files -n python3-%{srcname}-testsdk
%doc README.md
%{python3_sitelib}/azure/cli/testsdk
%{python3_sitelib}/azure_cli_testsdk-%{testsdk_version}.dist-info/


%changelog
* Mon Feb 14 2022 Major Hayden <major@redhat.com> 2.33.1-1
- Update to 2.33.1

* Tue Feb 08 2022 Major Hayden <major@redhat.com> 2.33.0-2
- Allow older humanfriendly:

* Tue Feb 08 2022 Major Hayden <major@redhat.com> 2.33.0-1
- Update to 2.33.0

* Wed Jan 19 2022 Major Hayden <major@redhat.com> 2.32.0-7
- Disable azure-cli command modules tests

* Wed Jan 19 2022 Major Hayden <major@redhat.com> 2.32.0-6
- Allow for newer argcomplete

* Mon Jan 17 2022 Major Hayden <major@redhat.com> 2.32.0-5
- Align tests with upstream pytest arguments

* Mon Jan 17 2022 Major Hayden <major@redhat.com> 2.32.0-4
- Update humanfriendly version for F35

* Thu Jan 06 2022 Major Hayden <major@redhat.com> 2.32.0-3
- Synchronize versions for Fedora 35

* Wed Jan 05 2022 Major Hayden <major@redhat.com> 2.32.0-2
- Allow newer requests

* Tue Jan 04 2022 Major Hayden <major@redhat.com> 2.32.0-1
- 🚀 Update to 2.32.0

* Wed Dec 15 2021 Major Hayden <major@redhat.com> 2.31.0-2
- Disable keyvault_hsm_security_domain test

* Wed Dec 15 2021 Major Hayden <major@redhat.com> 2.31.0-1
- Update to 2.31.0

* Fri Nov 12 2021 Major Hayden <major@redhat.com> 2.30.0-5
- Skip test_azconfig_import_export test

* Fri Nov 12 2021 Major Hayden <major@redhat.com> 2.30.0-4
- Lower the humanfriendly requirement

* Fri Nov 12 2021 Major Hayden <major@redhat.com> 2.30.0-3
- Update bash completion handling

* Wed Nov 10 2021 Major Hayden <major@redhat.com> 2.30.0-2
- Disable a few more azure-cli tests

* Tue Nov 09 2021 Major Hayden <major@redhat.com> 2.30.0-1
- Update to 2.30.0

* Mon Nov 01 2021 Major Hayden <major@mhtx.net> 2.29.2-4
- Disable test_keyvault_hsm_security_domain test

* Mon Nov 01 2021 Major Hayden <major@mhtx.net> 2.29.2-3
- Allow humanfriendly>=8.2 for F35

* Fri Oct 29 2021 Major Hayden <major@mhtx.net> 2.29.2-2
- Switch to testing style used by azdev

* Fri Oct 29 2021 Major Hayden <major@mhtx.net> 2.29.2-1
- Update to 2.29.2

* Fri Oct 22 2021 Major Hayden <major@mhtx.net> 2.29.1-3
- Remove debug code

* Fri Oct 22 2021 Major Hayden <major@mhtx.net> 2.29.1-2
- Enable testing for azure-cli components

* Thu Oct 21 2021 Major Hayden <major@mhtx.net> 2.29.1-1
- Update to 2.29.1

* Tue Oct 12 2021 Major Hayden <major@mhtx.net> 2.29.0-2
- Allow humanfriendly 8.2 or higher

* Tue Oct 12 2021 Major Hayden <major@mhtx.net> 2.29.0-1
- Update to 2.29.0

* Mon Oct 04 2021 Major Hayden <major@mhtx.net> 2.28.0-4
- Allow for newer versions of humanfriendly

* Mon Sep 13 2021 Major Hayden <major@mhtx.net> 2.28.0-3
- Switch to rpmautospec

* Mon Sep 13 2021 Major Hayden <major@mhtx.net> 2.28.0-2
- Allow newer versions of python3-scp

* Wed Sep 08 2021 Major Hayden <major@mhtx.net> 2.28.0-1
- Update to 2.28.0

* Mon Aug 23 2021 Major Hayden <major@mhtx.net> 2.27.2-1
- Update to azure-cli 2.27.2

* Wed Aug 11 2021 Major Hayden <major@mhtx.net> 2.27.1-1
- Update to 2.27.1

* Mon Aug 09 2021 Major Hayden <major@mhtx.net> 2.27.0-1
- Update to 2.27.0

* Sat Aug 07 2021 Major Hayden <major@mhtx.net> 2.26.1-1
- Initial import (#1986602)
